Opinions

## Opinions for Western Appellate District

#### Step 1. Select or Change Court

Court:

#### Step 2. Search Opinions ...

Need Help?

#### ... OR View By Date

Year of Opinion:
Show all Opinions for Year Hide all Opinions
Click on a date below to view opinions.

WDOrder05-06-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
WD76864: Overview/Summary Mark Kershaw, et al vs. City of Kansas City, Missouri Author: Karen King Mitchell, Judge Vote: Reversed & remanded. Ellis, P.J. and Gabbert, JJ., concur
WD76724: Overview/Summary Manuel H. Lopez, on Behalf of Himself and All Others Similarly Situated vs. H&R Block, Inc., et al Author: Victor C. Howard, Presiding Judge Vote: Reversed & remanded. Ahuja, JJ. and Witt, JJ., concur
WDOrder04-29-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
WD76783: Overview/Summary Mary Kingsley vs. Richard McDonald Author: Alok Ahuja, Judge Vote: Reversed & remanded. Howard, P.J. and Witt, JJ., concur
WD76778: Overview/Summary Richard Brown, Et Al vs. Susan Brown-Thill Author: Alok Ahuja, Judge Vote: Reversed & remanded. Howard, P.J. and Gabbert, JJ., concur
WD76619: Overview/Summary Star Development Corporation vs. Urgent Care Associates, Inc., et al Author: Lisa White Hardwick, Judge Vote: Affirmed & remanded. Welsh, C.J. Presiding and McBeth, Sp. J., concur
WD76581: Overview/Summary In the Estate of Kevin N. Merritt, Deceased, By and Through Its Duly Appointed Personal Representative, Monique Merritt vs. Rebecca L. Wachter Fidelity Brokerage Services, LLC Author: Anthony Rex Gabbert, Presiding Judge Vote: Reversed & remanded. Howard, JJ. and Newton, JJ., concur
WD76534: Overview/Summary Janet Hurst vs. Kansas City Missouri School District Author: Joseph M. Ellis, Presiding Judge Vote: Affirmed & remanded. Mitchell, JJ. and Gabbert, JJ., concur
WD76508: Overview/Summary Stacey L. Deane vs. Missouri Employers Mutual Insurance Company Author: Joseph M. Ellis, Presiding Judge Vote: Affirmed. Mitchell, JJ. and Gabbert, JJ., concur
WD76380: Overview/Summary Jimmie Lee Taylor vs. The Bar Plan Mutual Insurance Company, Et Al Author: Gary D. Witt, Judge Vote: Reversed. Reversed. Martin, P.J., concurs, Fischer, Sp. J., concurs in part and dissents in part in a separate opinion
WD76086: Overview/Summary Ray Charles Bate and Deborah Sue Bate vs. Greenwich Insurance Company Author: Cynthia L. Martin, Judge Vote: Affirmed & remanded. Newton, P.J. and Pfeiffer, JJ., concur
WD75986: Overview/Summary Jerry Allan Ridge, Jr. vs. Director of Revenue Author: Anthony Rex Gabbert, Presiding Judge Vote: Affirmed. Howard, JJ. and Newton, JJ., concur
WD75585 Consolidated with WD75619: Overview/Summary Stephen A. Oliver, Et Al vs. Ford Motor Credit Company, LLC, Et Al Author: Anthony Rex Gabbert, Presiding Judge Vote: Affirmed. Howard, JJ. and Newton, JJ., concur
WDOrder04-22-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
WD76933: Overview/Summary Priscella Gilley vs. Missouri Public Entity Risk Management Fund Author: Mark D. Pfeiffer, Judge Vote: Affirmed. Newton, p.J. and Martin, JJ., concur
WD76647: Overview/Summary State of Missouri vs. Stephen D. Wright Author: Karen King Mitchell, Judge Vote: Dismissed & remanded. Martin, P.J. and Pfeiffer, JJ., concur
WD76646: Overview/Summary State of Missouri vs. Travis Lovett Author: Joseph M. Ellis, Judge Vote: Dismissed & remanded. Welsh, C.J. and Rhodes, Sp. J., concur
WD76470: Overview/Summary Rocking H Trucking, LLC, and John Payne Harrison, IV vs. H.B.I.C., LLC, Michelle Alderson, and David Fenton, D.V.M. Author: Mark D. Pfeiffer, Judge Vote: Dismissed. Newton, P.J. and Martin, JJ., concur
WD76419: Overview/Summary Christopher Estes vs. Cole County of Missouri, et al Author: Cynthia L. Martin, Judge Vote: Affirmed. Newton, P.J. and Pfeiffer, JJ., concur
WD76356: Overview/Summary Ericka J. Sauvain, Amy Leigh Sauvain, by Next Friend Ericka J. Sauvain, and Bonnie S. Hughes vs. Acceptance Indemnity Insurance Company Author: Mark D. Pfeiffer, Judge Vote: Affirmed. Martin, P.J. and Mitchell, JJ., concur
WD76304: Overview/Summary State of Missouri vs. Henry L. Sutton, III Author: Cynthia L. Martin, Judge Vote: Affirmed. Newton, P.J. and Pfeiffer, JJ., concur
WDOrder04-15-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
WD76589: Overview/Summary Brian Hauge and Susan Hanley vs. Trustees of Highlands of Chesterfield Author: James E. Welsh, Chief Judge Vote: Affirmed. Ellis, JJ. and Russell, Sp. J., concur
WD76552: Overview/Summary In the Matter of the Estate of M. Stanley Ginn, Deceased, Nancy Almond, Personal Representative (Administrator De Bonis Non) and Individually vs. Carrie Almond, et al Author: James E. Welsh, Chief Judge Vote: Affirmed. Ellis, JJ. and Russell, Sp. J., concur
WD76414: Overview/Summary Kwang H. Kim vs. Won Il Kim Author: James E. Welsh, Chief Judge Vote: Dismissed. Ellis, JJ. and Newton, JJ., concur
WD76228: Overview/Summary David A. Kline vs. State of Missouri Author: Alok Ahuja, Judge Vote: Affirmed. Witt, P.J. and Hardwick, JJ., concur
WD76102: Overview/Summary Central Bank of Kansas City vs. donald Perry, et ux Author: Alok Ahuja, Presiding Judge Vote: Affirmed. Newton, JJ. and Gabbert, JJ., concur
WD75982: Overview/Summary Cindy Walden vs. Kenneth Smith and American Family Mutual Insurance Company Author: Cynthia L. Martin, Presiding Judge Vote: Affirmed. Pfeiffer, JJ., and Mitchell, JJ., concur
WD75944: Overview/Summary Deborah Barkley vs. McKeever Enterprises, Inc. D/B/A Price Chopper Author: Thomas H. Newton, Judge Vote: Affirmed. Ahuja, P.J., concurs Gabbert, JJ., dissents in a separate opinion
WDOrder04-08-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
WD77031: Overview/Summary State of Missouri ex rel Ideker, Inc. vs. The Honorable Jack Grate Author: Alok Ahuja, Judge Vote: Writ made absolute. Hardwick, P.J. and Mitchell, JJ., concur
WD76587: Overview/Summary Larry Nance (Deceased) vs. Maxon Electric, Inc., and National Surety Corp., c/o Fireman's Fund Insurance CO Author: Mark D. Pfeiffer, Judge Vote: Affirmed. Martin, P.J. and Mitchell, JJ., concur
WD76513: Overview/Summary Vincent Burton vs. SS Auto Inc. Author: Mark D. Pfeiffer, Judge Vote: Reversed & remanded with directions. Martin, P.J. and Mitchell, JJ., concur
WD76265: Overview/Summary Kevin Rowan vs. Coves North Homes Association Author: Victor C. Howard, Judge Vote: Reversed. Gabbert, P.J. and Newton, JJ., concur
WD75983: Overview/Summary Mindy L. Schler and Cindy L. Schler vs. Coves North Homes Association Author: Victor C. Howard, Presiding Judge Vote: Reversed. Gabbert, P.J. and Newton, JJ., concur
WD75596: Overview/Summary State of Missouri vs. Deandre J. Key Author: Karen King Mitchell, Judge Vote: Affirmed. Martin, P.J. and Pfeiffer, JJ., concur
WD75051 with WD75081: Overview/Summary Developer Services Corporation vs. Triple J. Construction, Inc., et al; Brazin Excavating, Inc. Author: Alok Ahuja, Judge Vote: Affirmed. Welsh, C.J., Presiding and Messina, Sp. J., concur
WDOrder04-01-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
WD76395: Overview/Summary State of Missouri vs. Kathryn Avent Author: Joseph M. Ellis, Judge Vote: Affirmed. Howard, JJ., concurs Pfeiffer, JJ., dissents in a separate opinion
WD76321: Overview/Summary Greg White vs. Cole county, Missouri, et al Author: Gary D. Witt, Presiding Judge Vote: Affirmed. Hardwick, JJ., and Ahuja, JJ., concur
WD76191 and WD76192: Overview/Summary The Village at Deer Creek Homeowners Association, Inc. vs. Mid-Continent Casualty Company Author: Cynthia L. Martin, Presiding Judge Vote: Affirmed in part, vacated & modified in part. Pfeiffer, JJ., and Mitchell, JJ., concur
WD76147: Overview/Summary Greg Hall vs. Lowell Fox and Gina Fox, et al Author: Anthony Rex Gabbert, Presiding Judge Vote: Affirmed. Howard, JJ., Fischer, SpJ., concur
WD75850: Overview/Summary State of Missouri vs. Daniel A. Ivey Author: Cynthia L. Martin, Presiding Judge Vote: Affirmed. Pfeiffer, JJ., and Mitchell, JJ., concur
WDOrder03-25-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
WD76689: Overview/Summary Troy Marlin Hill vs. Director of Revenue Author: Cynthia L. Martin, Presiding Judge Vote: Affirmed. Pfeiffer, JJ. and Mitchell, JJ., concur
WD76353: Overview/Summary AG Processing, Inc. vs. KCP&L Greater Missouri Operations Company; Missouri Public Service Commission; Triumph Foods, LLC Author: Lisa White Hardwick, Judge Vote: Dismissed. Witt, P.J. and Ahuja, JJ., concur
WD76046 and WD76387 and WD76388: Overview/Summary MacKenzie Sheridan vs. Division of Employment Security Author: Gary D. Witt, Presiding Judge Vote: Reversed & remanded. Hardwick, JJ. and Ahuja, JJ., concur
WD75765: Overview/Summary State of Missouri vs. Chane Nutt Author: Thomas H. Newton, Judge Vote: Reversed & remanded. Gabbert, P.J. and Howard, JJ., concur
WD75688: Overview/Summary Taqwa Thompson vs. State of Missouri Author: Victor C. Howard, Judge Vote: Affirmed. Gabbert, P.J. and Newton, JJ., concur
WDOrder03-18-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
WD75618: Overview/Summary Craig Herrington vs. Medevac Medical Response, Inc. Author: Thomas H. Newton, Judge Vote: Affirmed. Gabbert, P.J. and Howard, JJ., concur
WDOrder03-11-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
WD77056: Overview/Summary Rex A. Sinquefield and Travis Brown vs. Todd J. Jones and Missouri Roundtable for Life Author: Victor C. Howard, Judge Vote: Reversed & remanded. Welsh, C.J. and Newton, JJ., concur
WD76464: Overview/Summary The Salvation Army, Kansas and Western Missouri Division vs. Bank of America, et al Author: Mark D. Pfeiffer, Judge Vote: Affirmed. Martin, P.J. and Mitchell, JJ., concur
WD76155: Overview/Summary John Doe B.P. vs. Catholic Diocese of Kansas City-St. Joseph Author: Joseph M. Ellis, Judge Vote: Affirmed. Welsh, P.J., and Harman, Sp. J., concur
WD76128: Overview/Summary State of Missouri vs. Nelson E. Hopkins Author: Karen King Mitchell, Judge Vote: Dismissed. Martin, P.J. and Pfeiffer, JJ., concur
WD75934: Overview/Summary Tricia Barron vs. Division of Employment Security Author: Alok Ahuja, Judge Vote: Reversed & remanded. Witt, P.J. and Hardwick, JJ., concur
WD75863: Overview/Summary Tylicee S. Greene vs. Alliance Automotive, Inc. D/B/A JD Byrider and AutoBanc-2 Corporation D/B/A CNAC Author: Anthony Rex Gabbert, Judge Vote: Affirmed. Howard, P.J. and Ellis, JJ., concur
WDOrder03-04-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
WD76551: Overview/Summary In the Interest of: T.J.P., Jr. Juvenile Officer vs. T.L. (Mother) Author: Karen King Mitchell, Judge Vote: Affirmed. Martin, P.J. and Pfeiffer, JJ., concur
WD76396: Overview/Summary Charles Rademan vs. Al Scheppers Motor Company and Division of Employment Security Author: Anthony Rex Gabbert, Presiding Judge Vote: Dismissed. Howard, JJ., and Newton, JJ., concur
WD76381: Overview/Summary C.I.A. vs. T.E. Author: Victor c. Howard, Judge Vote: Dismissed as moot. Gabbert, P.J., and Newton, JJ., concur
WD76303: Overview/Summary Juvenile Officer W.J., S.C. and C.M. vs. A.S.M. (Mother) Author: Cynthia L. Martin, Presiding Judge Vote: Affirmed. Pfeiffer, JJ., and Mitchell, JJ., concur
WD75698: Overview/Summary State of Missouri vs. Joseph B. Sprofera Author: Joseph M. Ellis,Judge Vote: Affirmed in part, reversed & remanded in part. Welsh, C.J., and Witt, JJ., concur
WD75669: Overview/Summary Kenneth G. Middleton vs. State of Missouri Author: Anthony Rex Gabbert, Judge Vote: Affirmed. Ahuja, P.J., and Newton, JJ., concur
WDOrder02-25-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
WD76584: Overview/Summary Jenn Baier vs. Darden Restaurants, et al Author: Cynthia L. Martin, Presiding Judge Vote: Affirmed. Witt, JJ., and Fischer, Sp. J., concur
WD75582: Overview/Summary State of Missouri vs. Maura Celis-Garcia Author: Gary Witt, Presiding Judge Vote: Affirmed. Hardwick, JJ., and Ahuja, JJ., concur
WD74429: Overview/Summary City of Harrisonville vs. McCall Service Stations d/b/a Big Tank Oil, et al; The Missouri Petroleum Storage Tank Insurance Func Author: Alok Ahuja, Presiding Judge Vote: Affirmed as modified. Pfeiffer, JJ., and Gabbert, JJ., concur
WD74285: Overview/Summary State of Missouri vs. Trent L. Williams Author: Mark D. Pfeiffer, Judge Vote: Affirmed in part, reversed in part & remanded. Martin, P.J., and Mitchell, JJ., concur
WDOrder02-18-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
WD76644: Overview/Summary Jay Wolfe Used Cars of Blue Springs, LLC D/B/A Jay Wolfe Auto Outlet vs. Tyrell C. Jackson and Liane K. Jackson, on Their Own Behalf and on Behalf of All Others Similarly Situated Author: Cynthia L. Martin, Presiding Judge Vote: Affirmed. Witt, JJ., and Fischer, Sp. J., concur
WD75335: Overview/Summary State of Missouri vs. Antonio West Author: Gary D. Witt, Judge Vote: Affirmed. Martin, P.J., and Fischer, Sp. J.,, concur
WDOrder02-04-2013: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
WD76383: Overview/Summary Tracy Gunn vs. Division of Employment Security Author: Thomas H. Newton, Judge Vote: Affirmed. Ahuja, P.J., and Gabbert, JJ., concur
WD76338: Overview/Summary Dawn Stewart vs. Division of Employment Security Author: Anthony Rex Gabbert, Judge Vote: Reversed & remanded. Ahuja, P.J., and Newton, JJ., concur
WD76197: Overview/Summary Shana Medley vs. Division of Employment Security Author: Anthony Rex Gabbert, Presiding Judge Vote: Dismissed. Howard, JJ., and Newton, JJ., concur
WD75874: Overview/Summary Michael W. Schlax vs. State of Missouri Author: Lisa White Hardwick, Judge Vote: Affirmed. Witt, P.J., and Ahuja, JJ., concur
WDOrder01-28-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
WD76415: Overview/Summary Darnay Session vs. Director of Revenue Author: Anthony Rex Gabbert, Judge Vote: Affirmed. Ahuja, P.J. and Newton, JJ., concur
WD76174: Overview/Summary Blythe M. Groff vs. Robert M. Groff Author: Thomas H. Newton, Judge Vote: Dismissed as moot. Ahuja, P.J. and Gabbert, JJ., concur
WD76164 and WD76165: Overview/Summary In the Matter of Kansas City Power & Light Company's Request for Authority to Implement a General Rate Increase for Electric Service vs. Midwest Energy Consumers Group; Office of Public Counsel; Missouri Public Service Commission; Dogwood Energy, Inc.; Union Electric D/B/A Ameren Missouri Author: Anthony Rex Gabbert, Judge Vote: Dismissed. Newton, P.J. and Gabbert, JJ., concur
WD76105: Overview/Summary Joseph Sanders vs. Division of Employment Security Author: Cynthia L. Martin, Presiding Judge Vote: Affirmed. Pfeiffer, JJ. and Mitchell, JJ., concur
WDOrder01-21-2013: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
WD75532: Overview/Summary Shawn Stevens vs. Markirk Construction, Inc. Kirk Jones and Damar Development, Inc. Author: Lisa White Hardwick, Judge Vote: Reversed & remanded. Mitchell, P.J., and Witt, JJ., concur
WD75283: Overview/Summary Terrance Robinson vs. State of Missouri Author: Joseph M. Ellis,Judge Vote: Vacated in part & remanded. Pfeiffer, P.J., and Howard, JJ., concur
WD74940: Overview/Summary Adam Dutton vs. American Family Mutual Insurance Company Author: Gary D. Witt, Judge Vote: Reversed. Ellis, JJ., Howard, JJ., Newton JJ., Pfeiffer., JJ Gabbert. JJ.,Concur, Dissenting Opinion by Judge Ahuja., Joined by Welsh, CJ., Hardwick, JJ., Mitchell, JJ., Dissenting Opinion by Judge Martin, Joined by Welsh, CJ., Hardwick, JJ., Ahuja, JJ., Mitchell, JJ
WDOrder01-14-2014: Orders Pursuant to Rules 30.25(b) and/or 84.16(b)
WD76602 amd WD76603: Overview/Summary Gary Scott vs. Treasurer of The State of Missouri-Custodian of The Second Injury Fund Author: Mark D. Pfeiffer, Presiding Judge Vote: Reversed & remanded. Ellis, JJ. and Howard, JJ., concur
WD76509: Overview/Summary In The Matter of The Application of Laclede Gas Company D/B/A Missouri Gas Energy, For Approval to Change its Infrastructure System Replacement Surcharge; Public Service Commission of The State of Missouri vs. The Office of Public Counsel Author: James Edward Welsh, Chief Judge Presiding Vote: Affirmed. Martin, JJ. and Robb, Sp. J., concur
WD76280: Overview/Summary In The Matter of Foreclosure of Liens for Delinquent Land Taaxes By Action in Rem: Collector of Revenue, by and Through The Director of Collections for Jackson County, Missouri vs. Terry Holton, Christina McIntosh Author: Karen King Mitchell, Presiding Judge Vote: Reversed with directions. Hardwick, JJ. and Witt, JJ., concur
WD76276 and WD76347: Overview/Summary Federal National Mortgage Association and Nationstar Mortgage, LLC vs. Jeffrey A. Conover, et al Author: Mark D. Pfeiffer, Presiding Judge Vote: Reversed & remanded. Ellis, JJ. and Howard, JJ., concur
WD76068 & WD76110: Overview/Summary City of North Kansas City, Missouri vs. K.C. Beaton Holding Company, LLC, et al; Platte Valley Bank of Missouri and Keith Hicklin Author: James E. Welsh, Chief Judge Vote: Affirmed. Cross Appeal dismissed. Martin, JJ. and robb, Sp. J., concur
WD75878: Overview/Summary State of Missouri vs. Hector C. Castro Author: Gary D. Witt, Judge Vote: Dismissed as moot. Mitchell, P.J. and Hardwick, JJ., concur